@@ -1,6 +1,6 @@
 #!/bin/bash
 DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )";
-PROCDUMPPATH=$(readlink -m "$DIR/../../../bin/procdump");
+PROCDUMPPATH=$(readlink -m "$DIR/$1");
 TESTWEBAPIPATH=$(readlink -m "$DIR/../TestWebApi");
 HELPERS=$(readlink -m "$DIR/../helpers.sh");
 
@@ -19,7 +19,7 @@ if [ $? -eq -1 ]; then
     exit 1
 fi
 
-sudo $PROCDUMPPATH -log -m 10,20,30 -w TestWebApi&
+sudo $PROCDUMPPATH -log stdout -m 10,20,30 -w TestWebApi&
 
 # waiting for procdump child process
 PROCDUMPCHILDPID=-1
